LlmBindings class

Bindings for Rust code

Constructors

LlmBindings(DynamicLibrary dynamicLibrary)
The symbols are looked up in dynamicLibrary.
LlmBindings.fromLookup(Pointer<T> lookup<T extends NativeType>(String symbolName))
The symbols are looked up with lookup.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

detokenize_ids(Pointer<Uint32> _tokens, int _length) Pointer<Char>
download_model_ffi(Pointer<Char> model_name) Pointer<Char>
free_array(Pointer<Uint32> ptr, int length) → void
free_string(Pointer<Char> ptr) → void
load_model_ffi(Pointer<Char> model_name) Pointer<Char>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run_inference_c(Pointer<Char> input) Pointer<Char>
tokenize_text(Pointer<Char> _text) Pointer<Void>
tokenize_text_c(Pointer<Char> text, Pointer<UintPtr> length) Pointer<Uint32>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited